## Constraints file for the Digilent Nexys A7-100T
##
## Embedded Project Oberon OS
## Astrobe for RISC5 v7.2.0
## CFB Software
## https://www.astrobe.com
##
## CFB 18.01.2021 Nexys A7-100T modif to Nexys4 Cell RAM version by Pablo Cayuela

## Clock signal
set_property -dict { PACKAGE_PIN E3    IOSTANDARD LVCMOS33 } [get_ports { CLK100M }]
create_clock -add -name sys_clk_pin -period 10.00 -waveform {0 5} [get_ports {CLK100M}];


##Switches
set_property -dict { PACKAGE_PIN U9   IOSTANDARD LVCMOS33 } [get_ports {swi[0]}]
set_property -dict { PACKAGE_PIN U8   IOSTANDARD LVCMOS33 } [get_ports {swi[1]}]
set_property -dict { PACKAGE_PIN R7   IOSTANDARD LVCMOS33 } [get_ports {swi[2]}]
set_property -dict { PACKAGE_PIN R6   IOSTANDARD LVCMOS33 } [get_ports {swi[3]}]
set_property -dict { PACKAGE_PIN R5   IOSTANDARD LVCMOS33 } [get_ports {swi[4]}]
set_property -dict { PACKAGE_PIN V7   IOSTANDARD LVCMOS33 } [get_ports {swi[5]}]
set_property -dict { PACKAGE_PIN V6   IOSTANDARD LVCMOS33 } [get_ports {swi[6]}]
set_property -dict { PACKAGE_PIN V5   IOSTANDARD LVCMOS33 } [get_ports {swi[7]}]

## LEDs
set_property -dict { PACKAGE_PIN T8   IOSTANDARD LVCMOS33 } [get_ports {leds[0]}]
set_property -dict { PACKAGE_PIN V9   IOSTANDARD LVCMOS33 } [get_ports {leds[1]}]
set_property -dict { PACKAGE_PIN R8   IOSTANDARD LVCMOS33 } [get_ports {leds[2]}]
set_property -dict { PACKAGE_PIN T6   IOSTANDARD LVCMOS33 } [get_ports {leds[3]}]
set_property -dict { PACKAGE_PIN T5   IOSTANDARD LVCMOS33 } [get_ports {leds[4]}]
set_property -dict { PACKAGE_PIN T4   IOSTANDARD LVCMOS33 } [get_ports {leds[5]}]
set_property -dict { PACKAGE_PIN U7   IOSTANDARD LVCMOS33 } [get_ports {leds[6]}]
set_property -dict { PACKAGE_PIN U6   IOSTANDARD LVCMOS33 } [get_ports {leds[7]}]

##Buttons
set_property -dict { PACKAGE_PIN F15   IOSTANDARD LVCMOS33 } [get_ports {btn[0]}]
set_property -dict { PACKAGE_PIN T16   IOSTANDARD LVCMOS33 } [get_ports {btn[1]}]
set_property -dict { PACKAGE_PIN R10   IOSTANDARD LVCMOS33 } [get_ports {btn[2]}]
set_property -dict { PACKAGE_PIN V10   IOSTANDARD LVCMOS33 } [get_ports {btn[3]}]

##Pmod Headers
##Pmod Header JB
set_property -dict { PACKAGE_PIN G14   IOSTANDARD LVCMOS33 } [get_ports {SS[1]}]
set_property -dict { PACKAGE_PIN P15   IOSTANDARD LVCMOS33 } [get_ports {MOSI[1]}]
set_property -dict { PACKAGE_PIN V11   IOSTANDARD LVCMOS33 } [get_ports {MISO[1]}]
set_property -dict { PACKAGE_PIN V15   IOSTANDARD LVCMOS33 } [get_ports {SCLK[1]}]
set_property PULLUP true [get_ports {MISO[1]}]

##Pmod Header JC
set_property -dict { PACKAGE_PIN K2    IOSTANDARD LVCMOS33 } [get_ports {GPIO[0]}]
set_property -dict { PACKAGE_PIN E7    IOSTANDARD LVCMOS33 } [get_ports {GPIO[1]}]
set_property -dict { PACKAGE_PIN J3    IOSTANDARD LVCMOS33 } [get_ports {GPIO[2]}]
set_property -dict { PACKAGE_PIN J4    IOSTANDARD LVCMOS33 } [get_ports {GPIO[3]}]
set_property -dict { PACKAGE_PIN K1    IOSTANDARD LVCMOS33 } [get_ports {GPIO[4]}]
set_property -dict { PACKAGE_PIN E6    IOSTANDARD LVCMOS33 } [get_ports {GPIO[5]}]
set_property -dict { PACKAGE_PIN J2    IOSTANDARD LVCMOS33 } [get_ports {GPIO[6]}]
set_property -dict { PACKAGE_PIN G6    IOSTANDARD LVCMOS33 } [get_ports {GPIO[7]}]


##Temperature Sensor
set_property -dict { PACKAGE_PIN F16   IOSTANDARD LVCMOS33 } [get_ports { SCL }]
set_property -dict { PACKAGE_PIN G16   IOSTANDARD LVCMOS33 } [get_ports { SDA }]

##Micro SD Connector
set_property -dict { PACKAGE_PIN E2    IOSTANDARD LVCMOS33 } [get_ports { SD_RESET }]
#set_property -dict { PACKAGE_PIN A1    IOSTANDARD LVCMOS33 } [get_ports { SD_CD }]; #IO_L9N_T1_DQS_AD7N_35 Sch=sd_cd
set_property -dict { PACKAGE_PIN B1    IOSTANDARD LVCMOS33 } [get_ports { SCLK[0] }]
set_property -dict { PACKAGE_PIN C1    IOSTANDARD LVCMOS33 } [get_ports { MOSI[0] }]
set_property -dict { PACKAGE_PIN C2    IOSTANDARD LVCMOS33 } [get_ports { MISO[0] }]
#set_property -dict { PACKAGE_PIN E1    IOSTANDARD LVCMOS33 } [get_ports { SD_DAT[1] }]; #IO_L18N_T2_35 Sch=sd_dat[1]
#set_property -dict { PACKAGE_PIN F1    IOSTANDARD LVCMOS33 } [get_ports { SD_DAT[2] }]; #IO_L18P_T2_35 Sch=sd_dat[2]
set_property -dict { PACKAGE_PIN D2    IOSTANDARD LVCMOS33 } [get_ports { SS[0] }]

##USB-RS232 Interface
set_property -dict { PACKAGE_PIN C4    IOSTANDARD LVCMOS33 } [get_ports { RxD }]
set_property -dict { PACKAGE_PIN D4    IOSTANDARD LVCMOS33 } [get_ports { TxD }]

set_property CONFIG_VOLTAGE 3.3 [current_design]
set_property CFGBVS VCCO [current_design]
set_property BITSTREAM.GENERAL.COMPRESS TRUE [current_design]
set_property BITSTREAM.CONFIG.CONFIGRATE 33 [current_design]
set_property CONFIG_MODE SPIx4 [current_design]
